@@ -1,14 +1,14 @@
 package App::Cinema::Controller::Root;
 
-use strict;
-use warnings;
-use base 'Catalyst::Controller';
+use Moose;
+use namespace::autoclean;
+BEGIN { extends qw/Catalyst::Controller/ };
 
 __PACKAGE__->config->{namespace} = '';
 
 sub index : Path : Args(0) {
 	my ( $self, $c ) = @_;
-	$c->res->redirect( $c->uri_for('menu') );
+	$c->res->redirect( $c->uri_for('/menu/home') );
 }
 
 sub default : Private {
